<?php
/**
 * The template for adding Featured Slider Options in Customizer
 *
 * @package foodland
 * @subpackage Foodland Pro
 * @since Foodland 1.0
 */
	
// Featured Slider Starts
	$wp_customize->add_panel( 'foodland_featured_slider_panel', array(
		'priority'       	=> 150,
		'capability'     	=> 'edit_theme_options',
		'title'          	=> __( 'Featured Slider Options', 'foodland' ),
		'description'    	=> __( 'Options for featured slider', 'foodland' ),
	)  );
	// Featured slider control section
	$wp_customize->add_section( 'foodland_featured_slider_controls', array(
		'priority'      	=> 10,
		'title'				=> __( 'Slider controls', 'foodland' ),
		'panel'				=> 'foodland_featured_slider_panel'
	) );

	$wp_customize->add_setting( 'foodland_theme_options[featured_slider_option]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_slider_option'],
		'sanitize_callback' => 'foodland_sanitize_select',
	) );

	$featured_slider_content_options = foodland_section_control_options();
	$choices = array();
	foreach ( $featured_slider_content_options as $featured_slider_content_option ) {
		$choices[$featured_slider_content_option['value']] = $featured_slider_content_option['label'];
	}

	$wp_customize->add_control( 'foodland_theme_options[featured_slider_option]', array(
		'choices'   		=> $choices,
		'label'    			=> __( 'Enable Slider on', 'foodland' ),
		'priority'			=> '1.1',
		'section'  			=> 'foodland_featured_slider_controls',
		'settings' 			=> 'foodland_theme_options[featured_slider_option]',
		'type'    			=> 'select',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[featured_slide_transition_delay]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_slide_transition_delay'],
		'sanitize_callback'	=> 'foodland_sanitize_number_range',
		'validate_callback'	=> 'foodland_validate_slide_transition_delay'
	) );

	$wp_customize->add_control( 'foodland_theme_options[featured_slide_transition_delay]' , array(
		'active_callback' 	=> 'foodland_is_slider_active',
		'description'     	=> __( 'Max. transition delay is 5 Sec.', 'foodland' ),
		'input_attrs'     	=> array(
			'min'          	=> 1,
			'max' 			=> 5,
			'style'        	=> 'width: 60px;'
		),
		'label'           	=> __( 'Transition Delay', 'foodland' ),
		'priority'        	=> '2.1.1',
		'section'         	=> 'foodland_featured_slider_controls',
		'settings'        	=> 'foodland_theme_options[featured_slide_transition_delay]',
		'type'            	=> 'number',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[featured_slide_transition_length]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_slide_transition_length'],
		'sanitize_callback'	=> 'foodland_sanitize_number_range',
		'validate_callback'	=> 'foodland_validate_slide_transition_length'
	) );

	$wp_customize->add_control( 'foodland_theme_options[featured_slide_transition_length]' , array(
		'active_callback' 	=> 'foodland_is_slider_active',
		'description'     	=> __( 'Max. transition delay is 5 Sec.', 'foodland' ),
		'input_attrs'     	=> array(
			'min'          	=> 1,
			'max'			=> 5,
			'style'        	=> 'width: 60px;'
		),
		'label'           	=> __( 'Transition Length', 'foodland' ),
		'priority'        	=> '2.1.2.1',
		'section'         	=> 'foodland_featured_slider_controls',
		'settings'        	=> 'foodland_theme_options[featured_slide_transition_length]',
		'type'            	=> 'number',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[featured_slide_loop]', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults['featured_slide_loop'],
		'sanitize_callback' => 'foodland_sanitize_select',
	) );

	$wp_customize->add_control( 'foodland_theme_options[featured_slide_loop]' , array(
		'active_callback' 	=> 'foodland_is_slider_active',
		'description'     	=> __( 'Select infinity to slide for infinite number of times OR select once to slide till all slides are visible.', 'foodland' ),
		'input_attrs'     	=> array(
			'style'        	=> 'width: 60px;'
		),
		'label'           	=> __( 'Loop', 'foodland' ),
		'priority'        	=> '2.1.2',
		'section'         	=> 'foodland_featured_slider_controls',
		'settings'        	=> 'foodland_theme_options[featured_slide_loop]',
		'type'            	=> 'select',
		'choices'         	=> array(
			'0'           	=> __( 'Infinity', 'foodland'),
			'1'            	=> __( 'Once', 'foodland') 
		),
	) );

	// Featured slider option section
	$wp_customize->add_section( 'foodland_featured_slider_options', array(
		'priority'      	=> 10,
		'title'				=> __( 'Slider options', 'foodland' ),
		'description'		=> __( 'This options work when slider is enabled from slider control options. Atleast 3 slides should be selected for slider to work properly.', 'foodland' ),
		'panel'				=> 'foodland_featured_slider_panel'
	) );
	
	$wp_customize->add_setting( 'foodland_theme_options[featured_slider_type]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_slider_type'],
		'sanitize_callback'	=> 'foodland_sanitize_select',
	) );

	//check if jetpack is active
	if( ( 'featured-food-menus' == $options['featured_slider_type'] ) && !class_exists('jetpack') ){
		$description  = sprintf( __( 'Food Menu requires ', 'foodland' ) .'<a target="_blank" href="'. esc_url( 'https://wordpress.org/plugins/jetpack/' ) .'">'. __( 'JetPack Plugin', 'foodland' ) . '</a>.' );
	}
	else{
		$description = __( 'Save and Refresh page if option is changed.', 'foodland' );
	}


	$featured_slider_types = foodland_featured_slider_types();
	$choices = array();

	foreach ( $featured_slider_types as $featured_slider_type ) {
		$choices[$featured_slider_type['value']] = $featured_slider_type['label'];
	}

	$wp_customize->add_control( 'foodland_theme_options[featured_slider_type]', array(
		'active_callback' 	=> 'foodland_is_slider_active',
		'choices'         	=> $choices,
		'label'           	=> __( 'Select Slider Type', 'foodland' ),
		'description'	  	=> $description,
		'priority'        	=> '2.1.3',
		'section'         	=> 'foodland_featured_slider_options',
		'settings'        	=> 'foodland_theme_options[featured_slider_type]',
		'type'            	=> 'select',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[featured_slide_number]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_slide_number'],
		'sanitize_callback'	=> 'foodland_sanitize_number_range',
		'validate_callback' => 'foodland_validate_featured_slide_number'
		
	) );

	$wp_customize->add_control( 'foodland_theme_options[featured_slide_number]' , array(
		'active_callback' 	=> 'foodland_is_slider_active',
		'description'     	=> __( 'Save and refresh the page if No. of Slides is changed.( Minimun = 3 and Maximum = 9 )', 'foodland' ),
		'input_attrs'     	=> array(
		'style'           	=> 'width: 45px;',
			'min'          	=> 3,
			'max'          	=> 9,
			'step'         	=> 1,
		),
		'label'           	=> __( 'Total No of Slides', 'foodland' ),
		'priority'        	=> '2.1.4',
		'section'         	=> 'foodland_featured_slider_options',
		'settings'        	=> 'foodland_theme_options[featured_slide_number]',
		'type'            	=> 'number',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[link_button_text]', array(
		'capability'        => 'edit_theme_options',
		'default'			=> $defaults['link_button_text'],
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'foodland_theme_options[link_button_text]', array(
		'active_callback' 	=> 'foodland_is_demo_slider_inactive',
		'label'           	=> __( 'Link Button Text', 'foodland' ),
		'description'		=> __( 'Leave empty to remove link button', 'foodland' ),
		'priority'        	=> '2.1.4.1',
		'section'         	=> 'foodland_featured_slider_options',
		'settings'        	=> 'foodland_theme_options[link_button_text]',
		'type'            	=> 'text',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[exclude_slider_post]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['exclude_slider_post'],
		'sanitize_callback'	=> 'foodland_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'foodland_theme_options[exclude_slider_post]', array(
		'active_callback' 	=> 'foodland_is_post_slider_active',
		'label'           	=> __( 'Check to exclude Slider post from Homepage posts', 'foodland' ),
		'priority'        	=> '2.1.4.2',
		'section'         	=> 'foodland_featured_slider_options',
		'settings'        	=> 'foodland_theme_options[exclude_slider_post]',
		'type'            	=> 'checkbox',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[featured_slider_select_category]', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'foodland_sanitize_category_list',
	) );

	$wp_customize->add_control( new Foodland_Customize_Multiple_Categories_Control( $wp_customize, 'foodland_featured_slider_select_category', array(
		'active_callback' 	=> 'foodland_is_category_slider_active',
		'label'           	=> __('Select Categories', 'foodland' ),
		'name'            	=> 'foodland_theme_options[featured_slider_select_category]',
		'priority'        	=> '10',
		'section'         	=> 'foodland_featured_slider_options',
		'settings'        	=> 'foodland_theme_options[featured_slider_select_category]',
		'type'            	=> 'dropdown-categories',
    ) ) );

	for ( $i=1; $i <=  $options['featured_slide_number'] ; $i++ ) {
		$wp_customize->add_setting( 'foodland_theme_options[featured_slider_post_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'foodland_sanitize_page',
		) );

		$wp_customize->add_control( 'foodland_theme_options[featured_slider_post_'. $i .']', array(
			'active_callback' 	=> 'foodland_is_post_slider_active',
			'input_attrs'     	=> array(
				'style'           => 'width: 70px;',
				'placeholder'   => __( 'Post Id', 'foodland' ),
			),
			'label'           	=> __( 'Featured Post', 'foodland' ) . ' # ' . $i ,
			'description'		=> __( 'Recommended post thumbnail image size is 450px * 315px', 'foodland' ),
			'priority'        	=>  '3' . $i,
			'section'         	=> 'foodland_featured_slider_options',
			'settings'        	=> 'foodland_theme_options[featured_slider_post_'. $i .']',
			'type'            	=> 'text',
			)
		);

		$wp_customize->add_setting( 'foodland_theme_options[featured_slider_page_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['dropdown_page_default'],
			'sanitize_callback'	=> 'foodland_sanitize_page',
		) );

		$wp_customize->add_control( 'foodland_theme_options[featured_slider_page_'. $i .']', array(
			'active_callback' 	=> 'foodland_is_page_slider_active',
			'label'           	=> __( 'Featured Page', 'foodland' ) . ' # ' . $i ,
			'description'		=> __( 'Recommended page thumbnail image size is 450px * 315px', 'foodland' ),
			'priority'        	=> '4' . $i,
			'section'         	=> 'foodland_featured_slider_options',
			'settings'        	=> 'foodland_theme_options[featured_slider_page_'. $i .']',
			'type'            	=> 'dropdown-pages',
		) );

		//nova menu jetpack support
		if( class_exists( 'jetpack' ) ){
			$wp_customize->add_setting( 'foodland_theme_options[featured_nova_menu_'. $i .']', array(
				'capability'		=> 'edit_theme_options',
				'default'			=> $defaults['dropdown_page_default'],
				'sanitize_callback'	=> 'sanitize_key',
			) );

			$wp_customize->add_control( new Foodland_Customize_Dropdown_Nova_Menu( $wp_customize, 'foodland_theme_options[featured_nova_menu_'. $i .']', array(
				'active_callback' => 'foodland_is_nova_menu_slider_active',
				'label'           => __( 'Food Menu ', 'foodland' ) . ' # ' . $i ,
				'description'	  => __( 'Recommender food menu thumbnail image size is 450px * 315px', 'foodland' ),
				'priority'        => '5' . $i,
				'section'         => 'foodland_featured_slider_options',
				'settings'        => 'foodland_theme_options[featured_nova_menu_'. $i .']',
				'type'            => 'nova-menu'
			) ) );

		}
		
		$wp_customize->add_setting( 'foodland_theme_options[featured_slider_note_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( new Foodland_Note_Control( $wp_customize, 'foodland_theme_options[featured_slider_note_'. $i .']', array(
			'active_callback' 	=> 'foodland_is_image_slider_active',
			'label'           	=> __( 'Featured Slide #', 'foodland' ) . $i,
			'priority'        	=> '60' . '.' . $i,
			'section'         	=> 'foodland_featured_slider_options',
			'settings'        	=> 'foodland_theme_options[featured_slider_note_'. $i .']',
			'type'            	=> 'description',
   		) ) );

		$wp_customize->add_setting( 'foodland_theme_options[featured_slider_image_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'absint',
		) );

		$wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'foodland_theme_options[featured_slider_image_'. $i .']' , array(
			'active_callback' 	=> 'foodland_is_image_slider_active',
			'label'           	=> __( 'Image', 'foodland' ),
			'description'     	=> __( 'Prefered image size is 450px * 315px', 'foodland'),
			'priority'        	=> '60' . '.' . $i . $i,
			'section'         	=> 'foodland_featured_slider_options',
			'settings'        	=> 'foodland_theme_options[featured_slider_image_'. $i .']',
			'flex_width'  	  	=> false, // Allow any width, making the specified value recommended. False by default.
    		'flex_height' 	  	=> false, // Require the resulting image to be exactly as tall as the height attribute (default).
    			'width'       	=> 450,
    			'height'      	=> 315,		
		) ) );


	    $wp_customize->add_setting( 'foodland_theme_options[featured_title_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control(  'foodland_theme_options[featured_title_'. $i .']', array(
			'active_callback' 	=> 'foodland_is_image_slider_active',
			'label'           	=> __( 'Title', 'foodland' ),
			'priority'        	=> '60' . '.' . $i . $i . $i,
			'section'         	=> 'foodland_featured_slider_options',
			'settings'        	=> 'foodland_theme_options[featured_title_'. $i .']',
			'type'            	=> 'text',
	    ) );

	    $wp_customize->add_setting( 'foodland_theme_options[featured_content_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'foodland_theme_options[featured_content_'. $i .']', array(
			'active_callback' 	=> 'foodland_is_image_slider_active',
			'label'           	=> __( 'Content', 'foodland' ),
			'priority'        	=> '60' . '.' . $i . $i . $i . $i,
			'section'         	=> 'foodland_featured_slider_options',
			'settings'        	=> 'foodland_theme_options[featured_content_'. $i .']',
			'type'            	=> 'textarea',
	    ) );
	    $wp_customize->add_setting( 'foodland_theme_options[featured_link_'. $i .']', array(
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control(  'foodland_theme_options[featured_link_'. $i .']', array(
			'active_callback' 	=> 'foodland_is_image_slider_active',
			'label'           	=> __( 'Link', 'foodland' ),
			'priority'        	=> '60' . '.' .$i . $i  . $i  . $i . $i,
			'section'         	=> 'foodland_featured_slider_options',
			'settings'        	=> 'foodland_theme_options[featured_link_'. $i .']',
			'type'				=> 'url',
		) );
	}
// Featured Slider End