<?php
/**
 * The template for adding promotional headline Options in Customizer
 *
 * @package foodland
 * @subpackage Foodland Pro
 * @since Foodland 1.0
 */

$options = foodland_get_theme_options(); // get values from theme options

// Featured page starts
    $wp_customize->add_section( 'foodland_promotional_headline', array(
		'title'   	 		=> __( 'Promotional Headline Options', 'foodland' ),
		'description'		=> __( 'Options for Promotional Headline', 'foodland' ),
		'priority' 			=> 200,
	) );

	$wp_customize->add_setting( 'foodland_theme_options[enable_promotional_headline_on]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['enable_promotional_headline_on'],
		'sanitize_callback' => 'foodland_sanitize_select',
	) );

	$promotional_options = foodland_section_control_options();
	$choices = array();
	foreach ( $promotional_options as $promotional_option ) {
		$choices[$promotional_option['value']] = $promotional_option['label'];
	}

	$wp_customize->add_control( 'foodland_theme_options[enable_promotional_headline_on]', array(
		'choices'  			=> $choices,
		'label'    			=> __( 'Enable on', 'foodland' ),
		'priority'			=> '1',
		'section'  			=> 'foodland_promotional_headline',
		'settings' 			=> 'foodland_theme_options[enable_promotional_headline_on]',
		'type'	  			=> 'select',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[promotional_headline_type]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['promotional_headline_type'],
		'sanitize_callback' => 'foodland_sanitize_select',
	) );

	$foodland_promotional_headline_types = foodland_promotional_headline_type();
	$choices = array();
	foreach ( $foodland_promotional_headline_types as $foodland_promotional_headline_type ) {
		$choices[$foodland_promotional_headline_type['value']] = $foodland_promotional_headline_type['label'];
	}

	$wp_customize->add_control( 'foodland_theme_options[promotional_headline_type]', array(
		'active_callback' 	=> 'foodland_is_promotional_headline_active',
		'label'           	=> __( 'Promotional Headline Type', 'foodland' ),
		'priority'        	=> '2',
		'section'         	=> 'foodland_promotional_headline',
		'settings'        	=> 'foodland_theme_options[promotional_headline_type]',
		'type'            	=> 'select',
		'choices'         	=> $choices,
	) );

	$wp_customize->add_setting( 'foodland_theme_options[promotional_headline_page]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['dropdown_page_default'],
		'sanitize_callback'	=> 'foodland_sanitize_page',
	) );

	$wp_customize->add_control( 'foodland_theme_options[promotional_headline_page]', array(
		'active_callback'	=> 'foodland_is_page_promotional_headline_active',
		'label'    			=> __( 'Select Page', 'foodland' ),
		'priority'			=> '3',
		'section'  			=> 'foodland_promotional_headline',
		'settings' 			=> 'foodland_theme_options[promotional_headline_page]',
		'type'	   			=> 'dropdown-pages',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[headline_title]', array(
		'capability'		=> 'edit_theme_options',
		'default' 			=> $defaults['headline_title'],
		'sanitize_callback'	=> 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'foodland_theme_options[headline_title]', array(
		'active_callback' 	=> 'foodland_is_custom_promotional_headline_active',
		'label'           	=> __( 'Headline Title', 'foodland' ),
		'description'     	=> __( 'Title for promotional headline', 'foodland' ),
		'priority'        	=> '4',
		'section'         	=> 'foodland_promotional_headline',
		'settings'        	=> 'foodland_theme_options[headline_title]',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[headline_content]', array(
		'capability'		=> 'edit_theme_options',
		'default' 			=> $defaults['headline_content'],
		'sanitize_callback'	=> 'esc_textarea'
	) );

	$wp_customize->add_control( 'foodland_theme_options[headline_content]', array(
		'active_callback' 	=> 'foodland_is_custom_promotional_headline_active',
		'label'           	=> __( 'Subheadline Text', 'foodland' ),
		'description'     	=> __( 'Content for Promotional Headline', 'foodland' ),
		'priority'        	=> '5',
		'section'         	=> 'foodland_promotional_headline',
		'settings'        	=> 'foodland_theme_options[headline_content]',
		'type'				=> 'textarea',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[promotional_headline_button_text]', array(
		'capability'		=> 'edit_theme_options',
		'default' 			=> $defaults['promotional_headline_button_text'],
		'sanitize_callback'	=> 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'foodland_theme_options[promotional_headline_button_text]', array(
		'active_callback' 	=> 'foodland_is_demo_promotional_headline_not_active',
		'description'     	=> __( 'Appropriate Words: 3', 'foodland' ),
		'label'           	=> __( 'Link Button Text ', 'foodland' ),
		'priority'        	=> '6',
		'section'         	=> 'foodland_promotional_headline',
		'settings'        	=> 'foodland_theme_options[promotional_headline_button_text]',
		'type'            	=> 'text',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[promotional_headline_url]', array(
		'capability'		=> 'edit_theme_options',
		'default' 			=> $defaults['promotional_headline_url'],
		'sanitize_callback'	=> 'esc_url_raw'
	) );

	$wp_customize->add_control( 'foodland_theme_options[promotional_headline_url]', array(
		'active_callback' 	=> 'foodland_is_custom_promotional_headline_active',
		'label'           	=> __( 'Link', 'foodland' ),
		'description'		=> __( 'Leave empty to remove link', 'foodland' ),
		'priority'        	=> '7',
		'section'         	=> 'foodland_promotional_headline',
		'settings'        	=> 'foodland_theme_options[promotional_headline_url]',
		'type'            	=> 'url',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[link_target]', array(
		'capability'		=> 'edit_theme_options',
		'default' 			=> $defaults['link_target'],
		'sanitize_callback' => 'foodland_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'foodland_theme_options[link_target]', array(
		'active_callback'  => 'foodland_is_custom_promotional_headline_active',
		'label'            => __( 'Check to Open Link in New Window/Tab', 'foodland' ),
		'priority'         => '8',
		'section'          => 'foodland_promotional_headline',
		'settings'         => 'foodland_theme_options[link_target]',
		'type'             => 'checkbox',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[promotional_headline_image]', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize,'foodland_theme_options[promotional_headline_image]', array(
		'active_callback' 	=> 'foodland_is_custom_promotional_headline_active',
		'section'         	=> 'foodland_promotional_headline',
		'settings'        	=> 'foodland_theme_options[promotional_headline_image]',
		'priority'        	=> '9',
		'label'           	=> __( 'Banner image', 'foodland' ),
		'description'		=> __( 'Click Remove to Disable image field. Recommended image size is 570x380 px', 'foodland' ),
		'width'           	=> 570,
		'height'          	=> 380,
		'flex_height'		=> true,
	) ) );
// Featured page ends