<?php
/**
 * The template for adding Featured Slider Options in Customizer
 *
 * @package foodland
 * @subpackage Foodland Pro
 * @since Foodland 1.0
 */

// Featured Slider Option starts
	$wp_customize->add_section( 'foodland_staff_members', array(
		'title'    			=> __( 'Staff Member Options', 'foodland' ),
		'description'    	=> __( 'Options for staff member', 'foodland' ),
		'priority' 			=> 500,
	) );


	$wp_customize->add_setting( 'foodland_theme_options[staff_member_option_on]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['staff_member_option_on'],
		'sanitize_callback' => 'foodland_sanitize_select',
	) );

	$staff_member_content_options = foodland_section_control_options();
	$choices = array();
	foreach ( $staff_member_content_options as $staff_member_content_option ) {
		$choices[$staff_member_content_option['value']] = $staff_member_content_option['label'];
	}

	$wp_customize->add_control( 'foodland_theme_options[staff_member_option_on]', array(
		'label'    			=> __( 'Enable Staff Member Section on', 'foodland' ),
		'priority' 			=> '10',
		'section'  			=> 'foodland_staff_members',
		'settings' 			=> 'foodland_theme_options[staff_member_option_on]',
		'type'     			=> 'select',
		'choices'  			=> $choices,
	) );

	$wp_customize->add_setting( 'foodland_theme_options[sfaff_member_title]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['sfaff_member_title'],
		'transport'			=> 'postMessage',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'foodland_theme_options[sfaff_member_title]', array(
			'selector'            => '#team-member h2.upercase',
			'render_callback'     => 'foodland_customize_partial_sfaff_member_title',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
		) );
	}

	$wp_customize->add_control( 'foodland_theme_options[sfaff_member_title]' , array(
		'active_callback' 	=> 'foodland_is_staff_member_not_disabled',
		'label'           	=> __( 'Title', 'foodland' ),
		'priority'        	=> '20',
		'section'         	=> 'foodland_staff_members',
		'settings'        	=> 'foodland_theme_options[sfaff_member_title]',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[staff_member_type]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['staff_member_type'],
		'sanitize_callback' => 'foodland_sanitize_select',
	) );

	$staff_member_content_options = foodland_staff_member_section_type();
	$choices = array();
	foreach ( $staff_member_content_options as $staff_member_content_option ) {
		$choices[$staff_member_content_option['value']] = $staff_member_content_option['label'];
	}

	$wp_customize->add_control( 'foodland_theme_options[staff_member_type]', array(
		'active_callback' 	=> 'foodland_is_staff_member_not_disabled',
		'label'           	=> __( 'Select Section Type', 'foodland' ),
		'priority'        	=> '35',
		'section'         	=> 'foodland_staff_members',
		'settings'        	=> 'foodland_theme_options[staff_member_type]',
		'type'            	=> 'select',
		'choices'         	=> $choices,
	) );

	$wp_customize->add_setting( 'foodland_theme_options[sfaff_member_layout]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['sfaff_member_layout'],
		'sanitize_callback'	=> 'foodland_sanitize_select',
	) );
	$choices = array();
	$layout_options = foodland_staff_member_layout_option();

	foreach ($layout_options as $layout_option ) {
		$choices[$layout_option['value']] = $layout_option['label'];
	}

	$wp_customize->add_control( 'foodland_theme_options[sfaff_member_layout]' , array(
		'active_callback' => 'foodland_is_staff_member_demo_not_active',
		'label'           => __( 'Layout Option', 'foodland' ),
		'description'     => __( 'Select layout for staff member', 'foodland'),
		'priority'        => '37',
		'section'         => 'foodland_staff_members',
		'settings'        => 'foodland_theme_options[sfaff_member_layout]',
		'type'            => 'select',
		'choices'		  => $choices,
		'input_attrs'     => array(
		'style'           => 'width: 60px;'
	) )	);

	$wp_customize->add_setting( 'foodland_theme_options[sfaff_member_no_of_staff]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['sfaff_member_no_of_staff'],
		'sanitize_callback'	=> 'foodland_sanitize_number_range',
		'validate_callback' => 'foodland_validate_number_of_staff_member'
	) );

	$wp_customize->add_control( 'foodland_theme_options[sfaff_member_no_of_staff]' , array(
		'active_callback' => 'foodland_is_staff_member_demo_not_active',
		'label'           => __( 'Staff number', 'foodland' ),
		'description'     => __( 'Save and refresh the page if Staff number is changed. Max Staff number is 12', 'foodland'),
		'priority'        => '40',
		'section'         => 'foodland_staff_members',
		'settings'        => 'foodland_theme_options[sfaff_member_no_of_staff]',
		'type'            => 'number',
		'input_attrs'     => array(
			'min'         => 3,
			'max'         => 12,
			'step'		  => 1,
			'style'       => 'width: 60px;'
		)
	) );

    //loop for featured post sliders
	for ( $i=1; $i <=  $options['sfaff_member_no_of_staff'] ; $i++ ) {
		$wp_customize->add_setting( 'foodland_theme_options[staff_member_note_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( new Foodland_Note_Control( $wp_customize, 'foodland_theme_options[staff_member_note_'. $i .']', array(
			'active_callback' 	=> 'foodland_is_staff_member_demo_not_active',
			'label'           	=> __( 'Staff Member #', 'foodland' ) . $i,
			'priority'        	=> '50'.'.'.$i,
			'section'         	=> 'foodland_staff_members',
			'settings'        	=> 'foodland_theme_options[staff_member_note_'. $i .']',
			'type'            	=> 'description',
   		) ) );

   		$wp_customize->add_setting( 'foodland_theme_options[staff_member_image_'.$i.']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'absint',
			) );

		$wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'foodland_theme_options[staff_member_image_'.$i.']' , array(
			'active_callback' 	=> 'foodland_is_staff_member_demo_not_active',
			'label'           	=> __( 'Banner Image', 'foodland' ),
			'description'     	=> __('Prefered image size is 366px * 355px.', 'foodland' ),
			'priority'        	=> '50'.'.'.$i .$i,
			'section'         	=> 'foodland_staff_members',
			'settings'        	=> 'foodland_theme_options[staff_member_image_'.$i.']',
			'flex_width'      	=> false, // Allow any width, making the specified value recommended. False by default.
			'flex_height'     	=> false, // Require the resulting image to be exactly as tall as the height attribute (default).
			'width'           	=> 366,
			'height'          	=> 355,

		) ) );


		$wp_customize->add_setting( 'foodland_theme_options[staff_member_position_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );


		$wp_customize->add_control( 'foodland_theme_options[staff_member_position_'. $i .']', array(
			'active_callback' => 'foodland_is_staff_member_demo_not_active',
			'label'           => __( 'Position', 'foodland' ),
			'description'     => __( 'Enter staff position', 'foodland' ),
			'priority'        =>  '50' .'.'. $i. $i. $i,
			'section'         => 'foodland_staff_members',
			'settings'        => 'foodland_theme_options[staff_member_position_'. $i .']',
			'type'            => 'text',
		) );


		$wp_customize->add_setting( 'foodland_theme_options[staff_member_name_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );


		$wp_customize->add_control( 'foodland_theme_options[staff_member_name_'. $i .']', array(
			'active_callback' => 'foodland_is_staff_member_demo_not_active',
			'label'           => __( 'Name', 'foodland' ),
			'description'	  => __( 'Enter staff name', 'foodland' ),
			'priority'        =>  '50'. '.'. $i. $i .$i .$i,
			'section'         => 'foodland_staff_members',
			'settings'        => 'foodland_theme_options[staff_member_name_'. $i .']',
			'type'            => 'text',
		) );

		$wp_customize->add_setting( 'foodland_theme_options[staff_member_link_'. $i .']', array(
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( 'foodland_theme_options[staff_member_link_'. $i .']', array(
			'active_callback' => 'foodland_is_staff_member_demo_not_active',
			'label'           => __( 'Link', 'foodland' ),
			'priority'        =>  '50' .'.' .$i .$i .$i .$i .$i,
			'section'         => 'foodland_staff_members',
			'settings'        => 'foodland_theme_options[staff_member_link_'. $i .']',
			'type'            => 'url',

		) );

		$wp_customize->add_setting( 'foodland_theme_options[staff_member_link_target_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'foodland_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'foodland_theme_options[staff_member_link_target_'. $i .']', array(
			'active_callback' => 'foodland_is_staff_member_demo_not_active',
			'label'           => __( 'Check to Open Link in New Window/Tab', 'foodland' ),
			'priority'        =>  '50' .'.' .$i .$i .$i .$i .$i,
			'section'         => 'foodland_staff_members',
			'settings'        => 'foodland_theme_options[staff_member_link_target_'. $i .']',
			'type'            => 'checkbox',
		) );
	}
// Featured Slider End