<?php
/**
 * The template for adding Special menu Options in Customizer
 *
 * @package foodland
 * @subpackage Foodland Pro
 * @since Foodland 1.0
 */

// Todays Special
	$options = foodland_get_theme_options(); // get values from theme options

	$wp_customize->add_section( 'foodland_todays_special', array(
		'priority' 			=> 300,
		'title'    			=> __( 'Today Special Options', 'foodland' ),
		'description'		=> __( 'Options for today special menu', 'foodland' ),
	) );

	// Special menu  control
	$wp_customize->add_setting( 'foodland_theme_options[show_todays_special_on]', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults['show_todays_special_on'],
		'sanitize_callback' => 'foodland_sanitize_select',
	) );

	$section_control_options = foodland_section_control_options();
	$choices = array();

	foreach ( $section_control_options as $section_control_option ) {
		$choices[$section_control_option['value']] = $section_control_option['label'];
	}

	$wp_customize->add_control( 'foodland_theme_options[show_todays_special_on]', array(
		'label'    			=> __( 'Enable Special Menu on', 'foodland' ),
		'priority' 			=> '1',
		'section'  			=> 'foodland_todays_special',
		'type'     			=> 'select',
		'choices'  			=> $choices,
	) );

	// Special menu title
	$wp_customize->add_setting( 'foodland_theme_options[todays_special_title]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['todays_special_title'],
		'transport'			=> 'postMessage',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'foodland_theme_options[todays_special_title]', array(
			'selector'            => '#menu-items h2.upercase',
			'render_callback'     => 'foodland_customize_partial_todays_special_title',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
		) );
	}

	$wp_customize->add_control( 'foodland_theme_options[todays_special_title]', array(
		'active_callback' 	=> 'foodland_todays_special_menu_not_disabled',
		'label'           	=> __( 'Special Menu Title', 'foodland' ),
		'priority'        	=>  '2',
		'section'         	=> 'foodland_todays_special',
	) );

	// Special menu type
	$wp_customize->add_setting( 'foodland_theme_options[todays_special_type]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['todays_special_type'],
		'sanitize_callback'	=> 'foodland_sanitize_select',
	) );

	$todays_special_types = foodland_todays_special_type();
	$choices = array();

	foreach ( $todays_special_types as $todays_special_type ) {
		$choices[$todays_special_type['value']] = $todays_special_type['label'];
	}

	//check is jetpack is active
	if( ( 'featured-food-menus' == $options['todays_special_type'] ) && !class_exists('jetpack') ){
		$description  = sprintf( __( 'Food Menu requires ', 'foodland' ) .'<a target="_blank" href="'. esc_url( 'https://wordpress.org/plugins/jetpack/' ) .'">'. __( 'JetPack Plugin', 'foodland' ) . '</a>.' );
	}
	else{
		$description = __( 'Visit Food menus options from dashboard.', 'foodland' );
	}

	$wp_customize->add_control( 'foodland_theme_options[todays_special_type]' , array(
		'active_callback' 	=> 'foodland_todays_special_menu_not_disabled',
		'label'           	=> __( 'Special menu Type', 'foodland' ),
		'description'		=> $description,
		'priority'        	=> '4',
		'section'         	=> 'foodland_todays_special',
		'type'            	=> 'select',
		'choices'         	=> $choices,
	) );

	if( class_exists( 'jetpack' ) ){
		// Special Number of menus
		$wp_customize->add_setting( 'foodland_theme_options[todays_special_no_of_menus]', array(
			'capability'        => 'edit_theme_options',
			'default'           => $defaults['todays_special_no_of_menus'],
			'sanitize_callback' => 'foodland_sanitize_number_range',
			'validate_callback'	=> 'foodland_validate_todays_special_no_of_menus'
		) );

		$wp_customize->add_control( 'foodland_theme_options[todays_special_no_of_menus]' , array(
			'active_callback' 	=> 'foodland_is_todays_special_demo_not_active',
			'label'           	=> __( 'No of Menu Items', 'foodland' ),
			'description'     	=> __( 'Save and refresh the page if No. of menu items is changed (Max no of menu items is 6 )', 'foodland' ),
			'priority'        	=> '5',
			'section'         	=> 'foodland_todays_special',
			'type'            	=> 'number',
			'input_attrs'     	=> array(
			'min'             	=> 1,
			'max'             	=> 8,
			'style'           	=> 'width: 60px;'
			),
		) );

		// Special menu select
		$no_of_menus = $options['todays_special_no_of_menus'];

		for( $i = 1; $i <= $no_of_menus; $i++ ){
			$wp_customize->add_setting( 'foodland_theme_options[todays_special_nova_menu_item_'.$i.']', array(
				'capability'        => 'edit_theme_options',
				'default'			=> $defaults['dropdown_page_default'],
				'sanitize_callback' => 'absint',
			) );

			$wp_customize->add_control( new Foodland_Customize_Dropdown_Nova_Menu( $wp_customize, 'foodland_theme_options[todays_special_nova_menu_item_'.$i.']', array(
				'active_callback' 	=> 'foodland_is_todays_special_demo_not_active',
				'label'           	=> __('Select Menu Item ', 'foodland' ).$i,
				'name'            	=> 'foodland_theme_options[todays_special_nova_menu_item_'.$i.']',
				'priority'        	=> '6'.'.'.$i,
				'section'         	=> 'foodland_todays_special',
				'type'            	=> 'nova-menu',
		    ) ) );	
		}
	}

	// Special menu banner image
	$wp_customize->add_setting( 'foodland_theme_options[todays_special_menu_banner_enable]', array(
		'capability'			=> 'edit_theme_options',
		'sanitize_callback'		=> 'foodland_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'foodland_theme_options[todays_special_menu_banner_enable]', array(
		'active_callback' 	=> 'foodland_is_todays_special_demo_not_active',
		'label'           	=> __( 'Enable Banner Image', 'foodland' ),
		'priority'        	=> '7',
		'section'         	=> 'foodland_todays_special',
		'settings'        	=> 'foodland_theme_options[todays_special_menu_banner_enable]',
		'type'            	=> 'checkbox',
	) );

	// Special menu banner image
	$wp_customize->add_setting( 'foodland_theme_options[todays_special_menu_banner]', array(
		'capability'			=> 'edit_theme_options',
		'sanitize_callback'		=> 'absint',
	) );

	$wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'foodland_theme_options[todays_special_menu_banner]' , array(
		'active_callback' 		=> 'foodland_is_todays_special_banner_active',
		'label'           		=> __( 'Banner Image', 'foodland' ),
		'description'     		=> __( 'Preferred image size 570x380 px <br>Click Remove to Disable image field.', 'foodland' ),
		'priority'        		=> '7',
		'section'         		=> 'foodland_todays_special',
		'flex_width'      		=> false, // Allow any width, making the specified value recommended. False by default.
		'width'           		=> 570,
		'height'          		=> 380,
		'flex_height'     		=> false,
	) ) );

	// Banner image url
	$wp_customize->add_setting( 'foodland_theme_options[todays_special_banner_url]', array(
		'capability'		=> 'edit_theme_options',
		//'default' 			=> $defaults['todays_special_banner_url'],
		'sanitize_callback'	=> 'esc_url_raw'
	) );

	$wp_customize->add_control( 'foodland_theme_options[todays_special_banner_url]', array(
		'active_callback' 	=> 'foodland_is_todays_special_banner_active',
		'label'           	=> __( 'Link', 'foodland' ),
		'description'		=> __( 'Leave empty to remove link', 'foodland' ),
		'priority'        	=> '8',
		'section'         	=> 'foodland_todays_special',
		'settings'        	=> 'foodland_theme_options[todays_special_banner_url]',
		'type'            	=> 'url',
	) );
// todays special items ends