<?php
/**
 * Implement Default Theme/Customizer Options
 *
 * @package Theme Palace
 * @subpackage Foodland Pro
 * @since Foodland 1.0
 */

/**
 * Returns the default options for foodland.
 *
 * @since Foodland 1.0
 */
function foodland_get_default_theme_options() {

	$theme_data = wp_get_theme();

	$default_theme_options = array(
		//Site Title an Tagline
		'logo'                                            => get_template_directory_uri() . '/images/logo.png',
		'logo_alt_text'                                   => '',
		'move_title_tagline'                              => 0,
		'disable_tagline_in_mobile'						  => 0,

		//Navigation
		'primary_menu_disable'                            => 0,

		//site title Color Options
		'site_title_tagline_color'						  => '#000000',
		'header_nav_menu_color'							  => '#000000',
		'theme_color'									  =>'#b5b5b5',

		//Header Image
		'enable_featured_header_image'                    => 'disabled',
		'featured_header_image_position'                  => 'after-header',
		'featured_header_image_url'                       => '',
		'featured_header_image_alt'                       => '',
		'featured_header_image_base'                      => 0,

		// Default page id for dropdown page select
		'dropdown_page_default'							  => 0,

		//Featured Slider Options
		'featured_slider_option'                          => 'disabled',
		'featured_slide_transition_delay'                 => '4',
		'featured_slide_transition_length'                => '1',
		'featured_slide_loop'                             => '0',
		'featured_slider_type'                            => 'demo-featured-slider',
		'featured_slide_number'                           => '3',
		'featured_slider_select_category'                 => array(),
		'link_button_text'								  => __( 'Order Now', 'foodland' ),
		'exclude_slider_post'                             => 0,
		
		//Promotional Headline option
		'enable_promotional_headline_on'				  => 'disabled',
		'promotional_headline_type'						  => 'demo-headline',
		'headline_title'								  => __( 'Tile for Promotional Headline', 'foodland' ),
		'headline_content'								  => __( 'This is promotion headline. You can edit this from Appearance -> Customize -> Promotional Headline -> Promotion Headline Content', 'foodland' ),
		'promotional_headline_page'						  => '2',
		'promotional_headline_button_text'				  => __( 'Read More', 'foodland'),
		'promotional_headline_url'						  => '',
		'link_target'									  => 1,

		//Todays Special Options
		'show_todays_special_on'					  	  => 'disabled',
		'todays_special_type'							  => 'demo-todays-special',
		'todays_special_title'							  => __( 'menus todays special', 'foodland' ),
		'todays_special_no_of_menus'					  => '6',

		//Homepage / Frontpage Options
		'disable_blog_options'						  	  => 0,
		'front_page_title'								  => __( 'Latest News', 'foodland' ),
		'front_page_category'                             => array(),
		'front_page_no_of_posts'						  => 5,
		'front_page_button_label'						  => __( 'Browse More', 'foodland'),
		'front_page_browse_url'							  => '',

		//Featured Content Options
		'featured_content_option'                         => 'disabled',
		'featured_content_layout'                         => 'layout-three',
		'featured_content_headline'                       => '',
		'featured_content_subheadline'                    => '',
		'featured_content_type'                           => 'demo-featured-content',
		'featured_content_show'                           => 'excerpt',

		//Staff Member Options
		'staff_member_option_on'						  => 'disabled',
		'sfaff_member_title' 							  => __( 'People who knows your appetite ', 'foodland'),
		'staff_member_type'								  => 'demo-staff-member',
		'sfaff_member_layout'							  => 'three-column',
		'sfaff_member_no_of_staff'						  => '4',

		//Theme Options starts

		//Contact form 7 shortcode
		'cf7_disable'									  => 0,
		'cf7_title'                                       => '',
		'cf7_sub_title'                                   => '',
		'cf7_shortcode' 								  => '',

		//Breadcrumb Options
		'breadcumb_option'                                => 0,
		'breadcumb_onhomepage'                            => 0,
		'breadcumb_seperator'                             => __( '&raquo;', 'foodland' ),

		//Comment Options
		'comment_option'                                  => 'use-wordpress-setting',
		'disable_notes'                                   => 0,
		'disable_website_field'                           => 0,

		//Custom CSS
		'custom_css'                                      => '',

		//Layout
		'content_layout'                                  => 'excerpt-image-left',
		'single_post_image_layout'                        => 'large',

		//Excerpt Options
		// Archive except
		'excerpt_length'                                  => '55',
		'excerpt_more_text'                               => __( 'Read More ...', 'foodland' ),
		// Featured slider except
		'slider_excerpt_length'                           => '30',

		//Pagination Options
		'pagination_type'                                 => 'default',

		//scrollup options
		'enable_scrollup'								  => 0,

		//Search Options
		'search_text'                                     => __( 'Search...', 'foodland' ),

		//Font Family Options
		'body_font'                                       => 'sans-serif',
		'title_font'                                      => 'sans-serif',
		'tagline_font'                                    => 'sans-serif',
		'content_title_font'                              => 'sans-serif',
		'content_font'                                    => 'sans-serif',
		'headings_font'                                   => 'sans-serif',
		'reset_typography'                                => 0,

		//Footer Editor Options
		'footer_content'                                  => sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Site Title with home URL', 'foodland' ), '[the-year]', '[site-link]' ) . ' &#124; ' . $theme_data->get( 'Name') . '&nbsp;' . __( 'by', 'foodland' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. $theme_data->get( 'Author' ) .'</a>',

		//Social Links
		'disable_social_icon'							  => 1,
		//Theme Options ends

		//Update Notifier
		'update_notifier'                                 => 0,

		//Reset all settings
		'reset_all_settings'                              => 0,
	);

	return apply_filters( 'foodland_default_theme_options', $default_theme_options );
}



/**
 * Returns an array of color schemes registered for foodland.
 *
 * @since Foodland 1.0
 */
function foodland_color_schemes() {
	$color_scheme_options= array(
		'light' => array(
			'value' => 'light',
			'label' => __( 'Light', 'foodland' ),
		),
		'dark'  => array(
			'value' => 'dark',
			'label' => __( 'Dark', 'foodland' ),
		),
	);

	return apply_filters( 'foodland_color_schemes', $color_scheme_options );
}

/**
 * Returns an array of content layout options registered for foodland.
 *
 * @since Foodland 1.0
 */
function foodland_get_archive_content_layout() {
	$layout_options = array(
		'excerpt-image-left'  => array(
			'value'               => 'excerpt-image-left',
			'label'               => __( 'Excerpt Image Left', 'foodland' ),
		),
		'excerpt-image-right' => array(
			'value'               => 'excerpt-image-right',
			'label'               => __( 'Excerpt Image Right', 'foodland' ),
		),
		'full-content'        => array(
			'value'               => 'full-content',
			'label'               => __( 'Show Full Content (No Featured Image)', 'foodland' ),
		),
	);

	return apply_filters( 'foodland_get_archive_content_layout', $layout_options );
}


/**
 * Returns an array of feature header enable options
 *
 * @since Foodland 1.0
 */
function foodland_enable_featured_header_image_options() {
	$enable_featured_header_image_options = array(
		'homepage'     => array(
			'value'        => 'homepage',
			'label'        => __( 'Homepage / Frontpage', 'foodland' ),
		),
		'exclude-home' => array(
			'value'        => 'exclude-home',
			'label'        => __( 'Excluding Homepage', 'foodland' ),
		),
		'entire-site'  => array(
			'value'        => 'entire-site',
			'label'        => __( 'Entire Site', 'foodland' ),
		),
		'disabled'     => array(
			'value'        => 'disabled',
			'label'        => __( 'Disabled', 'foodland' ),
		),
	);

	return apply_filters( 'foodland_enable_featured_header_image_options', $enable_featured_header_image_options );
}


/**
 * Returns an array of feature header image positions
 *
 * @since Foodland 1.0
 */
function foodland_featured_header_image_position_options() {
	$featured_header_image_position_options = array(
		'before_header' => array(
			'value'         => 'before-header',
			'label'         => __( 'Before Header', 'foodland' ),
		),
		
		'after-header'  => array(
			'value'         => 'after-header',
			'label'         => __( 'After Header', 'foodland' ),
		),
		
		'after_slider'  => array(
			'value'         => 'after-slider',
			'label'         => __( 'After Slider', 'foodland' ),
		),
	);

	return apply_filters( 'foodland_featured_header_image_position_options', $featured_header_image_position_options );
}

/**
 * Returns an array of content and control options registered for foodland.
 *
 * @since Foodland 1.0
 */
function foodland_section_control_options() {
	$section_control_options = array(
		'homepage'    => array(
			'value'       => 'homepage',
			'label'       => __( 'Static Homepage / Frontpage', 'foodland' ),
		),
		'entire-site' => array(
			'value'       => 'entire-site',
			'label'       => __( 'Entire Site', 'foodland' ),
		),
		'disabled'    => array(
			'value'       => 'disabled',
			'label'       => __( 'Disabled', 'foodland' ),
		),
	);

	return apply_filters( 'foodland_section_control_options', $section_control_options );
}

/**
 * Returns an array of promotional headline type options registered for foodland.
 *
 * @since Foodland 1.0
 */
function foodland_promotional_headline_type() {
	$promotion_headline_type = array(
		'demo-headline'   => array(
			'value'           => 'demo-headline',
			'label'           => __( 'Demo', 'foodland' ),
		),
		'page-headline'   => array(
			'value'           => 'page-headline',
			'label'           => __( 'Page', 'foodland' ),
		),
		'custom-headline' => array(
			'value'           => 'custom-headline',
			'label'           => __( 'Custom', 'foodland' ),
		),
	);

	return apply_filters( 'foodland_promotional_headline_type', $promotion_headline_type );
}

/**
 * Returns an array of content and control options registered for foodland.
 *
 * @since Foodland 1.0
 */
function foodland_todays_special_type() {
	$todays_special_type = array(
		'demo-todays-special'     => array(
			'value'                   => 'demo-todays-special',
			'label'                   => __( 'Today Special Demo', 'foodland' ),
		),
		'featured-food-menus' => array(
			'value'                   => 'featured-food-menus',
			'label'                   => __( 'Today Special Food Menus', 'foodland' ),
		),
	);

	return apply_filters( 'foodland_todays_special_type', $todays_special_type );
}

/**
 * Returns an array of content and control options registered for Staff member section.
 *
 * @since Foodland 1.0
 */
function foodland_staff_member_section_type() {
	$staff_member_section_type = array(
		'demo-staff-member'           => array(
			'value'                       => 'demo-staff-member',
			'label'                       => __( 'Demo Content', 'foodland' ),
		),
		'featured-image-staff-member' => array(
			'value'                       => 'featured-image-staff-member',
			'label'                       => __( 'Featured Image Content', 'foodland' ),
		),
	);

	return apply_filters( 'foodland_staff_member_section_type', $staff_member_section_type );
}

/**
 * Returns an array of  Staff member layout.
 *
 * @since Foodland 1.0
 */
function foodland_staff_member_layout_option() {
	$staff_member_layout_option = array(
		'three-column'           => array(
			'value'                       => 'three-column',
			'label'                       => __( 'Three Column', 'foodland' ),
		),
		'four-column' => array(
			'value'                       => 'four-column',
			'label'                       => __( 'Four Column', 'foodland' ),
		),
	);

	return apply_filters( 'foodland_staff_member_layout_option', $staff_member_layout_option );
}

/**
 * Returns an array of feature content types registered for foodland.
 *
 * @since Foodland 1.0
 */
function foodland_featured_content_types() {
	$featured_content_types = array(
		'demo-featured-content'  => array(
			'value'                  => 'demo-featured-content',
			'label'                  => __( 'Demo Featured Content', 'foodland' ),
		),
		'featured-post-content'  => array(
			'value'                  => 'featured-post-content',
			'label'                  => __( 'Featured Post Content', 'foodland' ),
		),
		'featured-page-content'  => array(
			'value'                  => 'featured-page-content',
			'label'                  => __( 'Featured Page Content', 'foodland' ),
		),
		'featured-food-menus'  => array(
			'value'                  => 'featured-food-menus',
			'label'                  => __( 'Featured Food Menus ( Jetpack )', 'foodland' ),
		),
		'featured-image-content' => array(
			'value'                  => 'featured-image-content',
			'label'                  => __( 'Featured Image Content', 'foodland' ),
		),
	);

	return apply_filters( 'foodland_featured_content_types', $featured_content_types );
}


/**
 * Returns an array of featured content options registered for foodland.
 *
 * @since Foodland 1.0
 */
function foodland_featured_content_layout_options() {
	$featured_content_layout_option = array(
		'layout-two'   => array(
			'value'        => 'layout-two',
			'label'        => __( '2 columns', 'foodland' ),
		),
		'layout-three' => array(
			'value'        => 'layout-three',
			'label'        => __( '3 columns', 'foodland' ),
		),
		'layout-four'  => array(
			'value'        => 'layout-four',
			'label'        => __( '4 columns', 'foodland' ),
		),
	);

	return apply_filters( 'foodland_featured_content_layout_options', $featured_content_layout_option );
}

/**
 * Returns an array of feature slider types registered for foodland.
 *
 * @since Foodland 1.0
 */
function foodland_featured_slider_types() {
	$featured_slider_types = array(
		'demo-featured-slider'     => array(
			'value'                    => 'demo-featured-slider',
			'label'                    => __( 'Demo Featured Slider', 'foodland' ),
		),
		'featured-post-slider'     => array(
			'value'                    => 'featured-post-slider',
			'label'                    => __( 'Featured Post Slider', 'foodland' ),
		),
		'featured-page-slider'     => array(
			'value'                    => 'featured-page-slider',
			'label'                    => __( 'Featured Page Slider', 'foodland' ),
		),
		'featured-category-slider' => array(
			'value'                    => 'featured-category-slider',
			'label'                    => __( 'Featured Category Slider', 'foodland' ),
		),
		'featured-image-slider'    => array(
			'value'                    => 'featured-image-slider',
			'label'                    => __( 'Featured Image Slider', 'foodland' ),
		),
		'featured-food-menus'       => array(
			'value'                    => 'featured-food-menus',
			'label'                    => __( 'Featured Food Menus ( Jetpack )', 'foodland' ),
		),
	);

	return apply_filters( 'foodland_featured_slider_types', $featured_slider_types );
}

/**
 * Returns an array of color schemes registered for foodland.
 *
 * @since Foodland 1.0
 */
function foodland_get_pagination_types() {
	$pagination_types = array(
		'default'                => array(
			'value'                  => 'default',
			'label'                  => __( 'Default(Older Posts/Newer Posts)', 'foodland' ),
		),
		'numeric'                => array(
			'value'                  => 'numeric',
			'label'                  => __( 'Numeric', 'foodland' ),
		),
		'infinite-scroll-click'  => array(
			'value'                  => 'infinite-scroll-click',
			'label'                  => __( 'Infinite Scroll (Click)', 'foodland' ),
		),
		'infinite-scroll-scroll' => array(
			'value'                  => 'infinite-scroll-scroll',
			'label'                  => __( 'Infinite Scroll (Scroll)', 'foodland' ),
		),
	);

	return apply_filters( 'foodland_get_pagination_types', $pagination_types );
}


/**
 * Returns an array of content featured image size.
 *
 * @since Foodland 1.0
 */
function foodland_single_post_image_layout_options() {
	$single_post_image_layout_options = array(
		'large'        => array(
			'value'        => 'large',
			'label'        => __( 'Large', 'foodland' ),
		),
		'full-size'    => array(
			'value'        => 'full-size',
			'label'        => __( 'Full size', 'foodland' ),
		),
		'header-image' => array(
			'value'        => 'header-image',
			'label'        => __( 'Header Image Size', 'foodland' ),
		),
		'disabled'     => array(
			'value'        => 'disabled',
			'label'        => __( 'Disabled', 'foodland' ),
		),
	);
	return apply_filters( 'foodland_single_post_image_layout_options', $single_post_image_layout_options );
}

/**
 * Returns an array of avaliable fonts registered for foodland.
 *
 * @since Foodland 1.0
 */
function foodland_avaliable_fonts() {
	$avaliable_fonts = array(
		'abril-fatface'       => array(
			'value'               => 'abril-fatface',
			'label'               => 'Abril Fatface',
		),	
		'allerta'             => array(
			'value'               => 'allerta',
			'label'               => '"Allerta", sans-serif',
		),
		'amaranth'            => array(
			'value'               => 'amaranth',
			'label'               => '"Amaranth", sans-serif',
		),
		'amatic-sc'           => array(
			'value'               => 'amatic-sc',
			'label'               => 'Amastic SC',
		),
		'andika'              => array(
			'value'               => 'andika',
			'label'               => 'Andika',
		),
		'antic-didone'        => array(
			'value'               => 'antic-didone',
			'label'               => 'Antic Didone',
		),
		'arapey'              => array(
			'value'               => 'arapey',
			'label'               => 'Arapey',
		),
		'arvo'				  => array(
			'value'			  	  => 'arvo',
			'label'				  => 'Arvo'
		),
		'asap'                => array(
			'value'               => 'asap',
			'label'               => 'Asap',
		),
		'bitter' 			  => array(
			'value'               => 'bitter',
			'label'               => 'Bitter',
		),
		'cantarell'           => array(
			'value'               => 'cantarell',
			'label'               => '"Cantarell", sans-serif',
		),
		'crete-round'        => array(
			'value'               => 'crete-round',
			'label'               => 'Crete Round',
		),
		'crimson-text'        => array(
			'value'               => 'crimson-text',
			'label'               => '"Crimson Text", sans-serif',
		),
		'cuprum'              => array(
			'value'               => 'cuprum',
			'label'               => '"Cuprum", sans-serif',
		),
		'dancing-script'      => array(
			'value'               => 'dancing-script',
			'label'               => '"Dancing Script", sans-serif',
		),
		'droid-sans'          => array(
			'value'               => 'droid-sans',
			'label'               => '"Droid Sans", sans-serif',
		),
		'droid-serif'         => array(
			'value'               => 'droid-serif',
			'label'               => '"Droid Serif", sans-serif',
		),
		'exo'                 => array(
			'value'               => 'exo',
			'label'               => '"Exo", sans-serif',
		),
		'exo-2'               => array(
			'value'               => 'exo-2',
			'label'               => '"Exo 2", sans-serif',
		),
		'flamenco'            => array(
			'value'               => 'flamenco',
			'label'               => 'Flamenco',
		),
		'istok-web'           => array(
			'value'               => 'istok-web',
			'label'               => '"Istok Web", sans-serif',
		),
		'josefin-sans'        => array(
			'value'               => 'josefin-sans',
			'label'               => '"Josefin Sans", sans-serif',
		),
		'lato'                => array(
			'value'               => 'lato',
			'label'               => '"Lato", sans-serif',
		),
		'libre-baskerville'   => array(
			'value'               => 'libre-baskerville',
			'label'               => '"Libre Baskerville",serif'
		),
		'lobster'             => array(
			'value'               => 'lobster',
			'label'               => '"Lobster", sans-serif',
		),
		'lora'                => array(
			'value'               => 'lora',
			'label'               => '"Lora", serif',
		),
		'medula-one'          => array(
			'value'               => 'medula-one',
			'label'               => 'Medula One',
		),
		'montserrat'          => array(
			'value'               => 'montserrat',
			'label'               => '"Montserrat", sans-serif',
		),
		'nobile'              => array(
			'value'               => 'nobile',
			'label'               => '"Nobile", sans-serif',
		),
		'noto-serif'          => array(
			'value'               => 'noto-serif',
			'label'               => '"Noto Serif", serif',
		),
		'neuton'              => array(
			'value'               => 'neuton',
			'label'               => '"Neuton", serif',
		),
		'open-sans'           => array(
			'value'               => 'open-sans',
			'label'               => '"Open Sans", sans-serif',
		),
		'oswald'              => array(
			'value'               => 'oswald',
			'label'               => '"Oswald", sans-serif',
		),
		'oxygen'				  => array(
			'value'			  	  => 'oxygen',
			'label'				  => 'Oxygen'
		),
		'patua-one'           => array(
			'value'               => 'patua-one',
			'label'               => '"Patua One", sans-serif',
		),
		'playfair-display'    => array(
			'value'               => 'playfair-display',
			'label'               => '"Playfair Display", sans-serif',
		),
		'pt-sans'             => array(
			'value'               => 'pt-sans',
			'label'               => '"PT Sansf", sans-serif',
		),
		'pt-serif'            => array(
			'value'               => 'pt-serif',
			'label'               => '"PT Serif", serif',
		),
		'quattrocento-sans'   => array(
			'value'               => 'quattrocento-sans',
			'label'               => '"Quattrocento Sans", sans-serif',
		),
		'roboto'              => array(
			'value'               => 'roboto',
			'label'               => '"Roboto", sans-serif',
		),
		'roboto-slab'         => array(
			'value'               => 'roboto-slab',
			'label'               => '"Roboto Slab", serif',
		),
		'sacramento'          => array(
			'value'               => 'sacramento',
			'label'               => 'sacramento',
		),
		'sans-serif'          => array(
			'value'               => 'sans-serif',
			'label'               => 'Sans-Serif, Helvetica, Arial',
		),
		'slabo-27px' 		  => array(
			'value'               => 'slabo-27px',
			'label'               => '"Salabo 27px"',
		),
		'source-sans-pro'     => array(
			'value'               => 'source-sans-pro',
			'label'               => '"Source Sans Pro", sans-serif',
		),
		'ubuntu'              => array(
			'value'               => 'ubuntu',
			'label'               => '"Ubuntu", sans-serif',
		),
		'varela'              => array(
			'value'               => 'varela',
			'label'               => '"Varela", sans-serif',
		),
		'verdana'             => array(
			'value'               => 'verdana',
			'label'               => 'Verdana, Geneva, sans-serif',
		),
		'yanone-kaffeesatz'   => array(
			'value'               => 'yanone-kaffeesatz',
			'label'               => '"Yanone Kaffeesatz", sans-serif',
		),
	);

	return apply_filters( 'foodland_avaliable_fonts', $avaliable_fonts );
}


/**
 * Returns list of social icons currently supported
 *
 * @since Foodland 1.0
*/
function foodland_get_social_icons_list() {
	$foodland_social_icons_list = array(
		'facebook_link'		=> array(
			'genericon_class' 	=> 'facebook-alt',
			'label' 			=> esc_html__( 'Facebook', 'foodland' )
			),
		'twitter_link'		=> array(
			'genericon_class' 	=> 'twitter',
			'label' 			=> esc_html__( 'Twitter', 'foodland' )
			),
		'googleplus_link'	=> array(
			'genericon_class' 	=> 'googleplus-alt',
			'label' 			=> esc_html__( 'Googleplus', 'foodland' )
			),
		'email_link'		=> array(
			'genericon_class' 	=> 'mail',
			'label' 			=> esc_html__( 'Email', 'foodland' )
			),
		'feed_link'			=> array(
			'genericon_class' 	=> 'feed',
			'label' 			=> esc_html__( 'Feed', 'foodland' )
			),
		'wordpress_link'	=> array(
			'genericon_class' 	=> 'wordpress',
			'label' 			=> esc_html__( 'WordPress', 'foodland' )
			),
		'github_link'		=> array(
			'genericon_class' 	=> 'github',
			'label' 			=> esc_html__( 'GitHub', 'foodland' )
			),
		'linkedin_link'		=> array(
			'genericon_class' 	=> 'linkedin',
			'label' 			=> esc_html__( 'LinkedIn', 'foodland' )
			),
		'pinterest_link'	=> array(
			'genericon_class' 	=> 'pinterest',
			'label' 			=> esc_html__( 'Pinterest', 'foodland' )
			),
		'flickr_link'		=> array(
			'genericon_class' 	=> 'flickr',
			'label' 			=> esc_html__( 'Flickr', 'foodland' )
			),
		'vimeo_link'		=> array(
			'genericon_class' 	=> 'vimeo',
			'label' 			=> esc_html__( 'Vimeo', 'foodland' )
			),
		'youtube_link'		=> array(
			'genericon_class' 	=> 'youtube',
			'label' 			=> esc_html__( 'YouTube', 'foodland' )
			),
		'tumblr_link'		=> array(
			'genericon_class' 	=> 'tumblr',
			'label' 			=> esc_html__( 'Tumblr', 'foodland' )
			),
		'instagram_link'	=> array(
			'genericon_class' 	=> 'instagram',
			'label' 			=> esc_html__( 'Instagram', 'foodland' )
			),
		'polldaddy_link'	=> array(
			'genericon_class' 	=> 'polldaddy',
			'label' 			=> esc_html__( 'PollDaddy', 'foodland' )
			),
		'codepen_link'		=> array(
			'genericon_class' 	=> 'codepen',
			'label' 			=> esc_html__( 'CodePen', 'foodland' )
			),
		'path_link'			=> array(
			'genericon_class' 	=> 'path',
			'label' 			=> esc_html__( 'Path', 'foodland' )
			),
		'dribbble_link'		=> array(
			'genericon_class' 	=> 'dribbble',
			'label' 			=> esc_html__( 'Dribbble', 'foodland' )
			),
		'skype_link'		=> array(
			'genericon_class' 	=> 'skype',
			'label' 			=> esc_html__( 'Skype', 'foodland' )
			),
		'digg_link'			=> array(
			'genericon_class' 	=> 'digg',
			'label' 			=> esc_html__( 'Digg', 'foodland' )
			),
		'reddit_link'		=> array(
			'genericon_class' 	=> 'reddit',
			'label' 			=> esc_html__( 'Reddit', 'foodland' )
			),
		'stumbleupon_link'	=> array(
			'genericon_class' 	=> 'stumbleupon',
			'label' 			=> esc_html__( 'Stumbleupon', 'foodland' )
			),
		'pocket_link'		=> array(
			'genericon_class' 	=> 'pocket',
			'label' 			=> esc_html__( 'Pocket', 'foodland' ),
			),
		'dropbox_link'		=> array(
			'genericon_class' 	=> 'dropbox',
			'label' 			=> esc_html__( 'DropBox', 'foodland' ),
			),
		'spotify_link'		=> array(
			'genericon_class' 	=> 'spotify',
			'label' 			=> esc_html__( 'Spotify', 'foodland' ),
			),
		'foursquare_link'	=> array(
			'genericon_class' 	=> 'foursquare',
			'label' 			=> esc_html__( 'Foursquare', 'foodland' ),
			),
		'twitch_link'		=> array(
			'genericon_class' 	=> 'twitch',
			'label' 			=> esc_html__( 'Twitch', 'foodland' ),
			),
		'website_link'		=> array(
			'genericon_class' 	=> 'website',
			'label' 			=> esc_html__( 'Website', 'foodland' ),
			),
		'phone_link'		=> array(
			'genericon_class' 	=> 'phone',
			'label' 			=> esc_html__( 'Phone', 'foodland' ),
			),
		'handset_link'		=> array(
			'genericon_class' 	=> 'handset',
			'label' 			=> esc_html__( 'Handset', 'foodland' ),
			),
		'cart_link'			=> array(
			'genericon_class' 	=> 'cart',
			'label' 			=> esc_html__( 'Cart', 'foodland' ),
			),
		'cloud_link'		=> array(
			'genericon_class' 	=> 'cloud',
			'label' 			=> esc_html__( 'Cloud', 'foodland' ),
			),
		'link_link'		=> array(
			'genericon_class' 	=> 'link',
			'label' 			=> esc_html__( 'Link', 'foodland' ),
			),
	);

	return apply_filters( 'foodland_social_icons_list', $foodland_social_icons_list );
}

/**
 * Returns an array of metabox Nova items Rating Options registered for foodland.
 *
 * @since Foodland 1.0
 */
function foodland_metabox_nova_item_rating() {
	$nova_rating = array(
		'one-star'    => array(
			'id'          => 'foodland-nova-item-rating',
			'value'       => '1',
			'label'       => __( '1 Star', 'foodland' ),
		),
		'two-stars'   => array(
			'id'          => 'foodland-nova-item-rating',
			'value'       => '2',
			'label'       => __( '2 Stars', 'foodland' ),
		),
		'three-stars' => array(
			'id'          => 'foodland-nova-item-rating',
			'value'       => '3',
			'label'       => __( '3 Stars', 'foodland' ),
		),
		'four-stars'  => array(
			'id'          => 'foodland-nova-item-rating',
			'value'       => '4',
			'label'       => __( '4 Stars', 'foodland' ),
		),
		'five-stars'  => array(
			'id'          => 'foodland-nova-item-rating',
			'value'       => '5',
			'label'       => __( '5 Stars', 'foodland' ),
		),
	);
	return apply_filters( 'foodland_nova_item_rating', $nova_rating );
}
/**
 * Returns an array of metabox header featured image options registered for foodland.
 *
 * @since Foodland 1.0
 */
function foodland_metabox_header_featured_image_options() {
	$header_featured_image_options = array(
		'default' => array(
			'id'      => 'foodland-header-image',
			'value'   => 'default',
			'label'   => __( 'Default', 'foodland' ),
		),
		'enable'  => array(
			'id'      => 'foodland-header-image',
			'value'   => 'enable',
			'label'   => __( 'Enable', 'foodland' ),
		),
		'disable' => array(
			'id'      => 'foodland-header-image',
			'value'   => 'disable',
			'label'   => __( 'Disable', 'foodland' )
		)
	);
	return apply_filters( 'header_featured_image_options', $header_featured_image_options );
}

/**
 * Returns an array of metabox featured image options registered for foodland.
 *
 * @since Foodland 1.0
 */
function foodland_metabox_featured_image_options() {
	$featured_image_options = array(
		'default'      => array(
			'id'           => 'foodland-featured-image',
			'value'        => 'default',
			'label'        => __( 'Default', 'foodland' ),
		),
		'header-image' => array(
			'id'           => 'foodland-featured-image',
			'value'        => 'header-image',
			'label'        => __( 'Header Image', 'foodland' )
		),
		'full'         => array(
			'id'           => 'foodland-featured-image',
			'value'        => 'full',
			'label'        => __( 'Full Image', 'foodland' )
		),
		'disable'      => array(
			'id'           => 'foodland-featured-image',
			'value'        => 'disable',
			'label'        => __( 'Disable Image', 'foodland' )
		)
	);
	return apply_filters( 'featured_image_options', $featured_image_options );
}

/**foodland_free_options
 * Checks if there are options already present from foodland free version and adds it to the foodland Pro theme options
 *
 * @since Foodland 1.0
 * @hook after_theme_switch
 */
function foodland_setup_options() {
	//Perform action only if theme_mods_foodland-pro[foodland_theme_options] does not exist
	if( !get_theme_mod( 'foodland_theme_options' ) ) {
		//Perform action only if theme_mods_foodland free version exists
		if ( $foodland_free_options = get_option ( 'theme_mods_foodland' ) ) {
			if ( isset( $foodland_free_options['foodland_theme_options'] ) ) {
				$foodland_pro_default_options = foodland_get_default_theme_options();

				$foodland_theme_options = $foodland_free_options;

				$foodland_theme_options['foodland_theme_options'] = array_merge( $foodland_pro_default_options , $foodland_free_options['foodland_theme_options'] );

				update_option( 'theme_mods_foodland-pro', $foodland_theme_options );
			}
		}
	}
}

add_action('after_switch_theme', 'foodland_setup_options');
