<?php
/**
 * The template for displaying Featured Slider
 *
 * @package Theme Palace
 * @subpackage Foodland Pro
 * @since Foodland 1.0 
 */

// Check slider status.
add_filter( 'foodland_filter_slider_status', 'foodland_check_slider_status' );

// Add slider to the theme.
add_action( 'foodland_before_content', 'foodland_add_featured_slider', 10 );

// Slider details.
add_filter( 'foodland_filter_slider_details', 'foodland_get_slider_details' );


if ( ! function_exists( 'foodland_get_slider_details' ) ) :
    /**
     * Slider details.
     *
     * @since Foodland 1.0
     *
     * @param array $input Slider details.
     */
    function foodland_get_slider_details( $input ) {

        $options = foodland_get_theme_options();

        $featured_slider_type        = $options[ 'featured_slider_type' ];
        $featured_slider_number      = $options[ 'featured_slide_number' ];
        $featured_slider_button_text = $options[ 'link_button_text' ];


        switch ( $featured_slider_type ) {
            case 'demo-featured-slider' :

                $demo_slider_images = array( 'slideimg-1.jpg', 'slideimg-2.jpg', 'slideimg-3.jpg', 'slideimg-4.jpg', 'slideimg-5.jpg', 'slideimg-6.jpg','sliderimg-2.jpg', 'sliderimg-4.jpg', 'sliderimg-6.jpg' );

                for( $i= 0; $i < $featured_slider_number; $i++ ){                    
                    $demo_slider[$i]['image']       = array( get_template_directory_uri() . '/images/' . $demo_slider_images[ $i ] );
                    $demo_slider[$i]['title']       = __( 'Chocolate ice-cream', 'foodland' );
                    $demo_slider[$i]['excerpt']     = __( 'Satisfy yourself with this chocolate ice-cream. Among out 20 different variety of ice-cream this one is most like by our customer.', 'foodland' );
                    $demo_slider[$i]['url']         = '#';
                } 

                $slides = array();
                $cnt    = 0;

                foreach ( $demo_slider as $key => $demo ) {

                    $slides[ $cnt ]['images']  = $demo['image'];
                    $slides[ $cnt ]['title']   = $demo['title'];
                    $slides[ $cnt ]['excerpt'] = $demo['excerpt'];
                    $slides[ $cnt ]['url']     = $demo['url'];

                    $cnt++;
                }
                if ( ! empty( $slides ) ) {
                    $input = $slides;
                }
            break;

            case 'featured-post-slider' :

                $ids = array();
                // get valid post id
                for ( $i = 1; $i <= absint( $featured_slider_number ); $i++ ) {
                    $id  = ! empty( $options[ 'featured_slider_post_' . $i ] ) ? $options[ 'featured_slider_post_' . $i ] : '';
                    if ( ! empty( $id ) ) {
                        $ids[] = absint( $id );
                    }
                }
                // Bail if no valid posts are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $qargs = array(
                    'posts_per_page' => absint( $featured_slider_number ),
                    'post__in'       => $ids,
                    'orderby'        => 'post__in',
                );

                // Fetch posts.
                $all_posts = get_posts( $qargs );
                $slides = array();

                if ( ! empty( $all_posts ) ) {

                    $cnt = 0;
                    foreach ( $all_posts as $key => $post ) {

                        if ( has_post_thumbnail( $post->ID ) ) {
                            $image_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'foodland-slider' );
                        } else{
                            $image_array = array ( get_template_directory_uri() . '/images/no-thumbnail-image-450x315.png' );
                        }
                        
                        $slides[ $cnt ]['images']  = $image_array;
                        $slides[ $cnt ]['title']   = $post->post_title;
                        $slides[ $cnt ]['excerpt'] = foodland_slider_excerpt_limit( $options['slider_excerpt_length'], $post );
                        $slides[ $cnt ]['url']     = get_permalink( $post->ID );

                        $cnt++;
                    }
                }
                if ( ! empty( $slides ) ) {
                    $input = $slides;
                }
            break;

            case 'featured-page-slider':

                $ids = array();

                for ( $i = 1; $i <= absint( $featured_slider_number ); $i++ ) {
                    $id = !empty( $options[ 'featured_slider_page_' . $i ] ) ? $options[ 'featured_slider_page_' . $i ] : '';
                    if ( ! empty( $id ) ) {
                        $ids[] = absint( $id );
                    }
                }
                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $qargs = array(
                    'post_type'      => 'page',
                    'posts_per_page' => absint( $featured_slider_number ),
                    'post__in'       => $ids,
                    'orderby'        => 'post__in',
                );

                // Fetch posts.
                $all_posts = get_posts( $qargs );
                $slides = array();

                if ( ! empty( $all_posts ) ) {

                    $cnt = 0;
                    foreach ( $all_posts as $key => $post ) {

                        if ( has_post_thumbnail( $post->ID ) ) {
                            $image_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'foodland-slider' );
                        }else{
                            $image_array = array ( get_template_directory_uri() . '/images/no-thumbnail-image-450x315.png' );
                        }

                        $slides[ $cnt ]['images']  = $image_array;
                        $slides[ $cnt ]['title']   = $post->post_title;
                        $slides[ $cnt ]['excerpt'] = foodland_slider_excerpt_limit( $options['slider_excerpt_length'], $post );
                        $slides[ $cnt ]['url']     = get_permalink( $post->ID );

                        $cnt++;
                    }
                }
                
                if ( ! empty( $slides ) ) {
                    $input = $slides;
                }
            break;

            case 'featured-category-slider':
                // Create an empty array
                $ids         = array();
                // Check if customizer category id array is not empty
                $category_id = !empty( $options['featured_slider_select_category'] ) ? $options['featured_slider_select_category'] : array();
                $ids         = array_filter( $category_id );
                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $qargs = array(
                    'ignore_sticky_posts' => 1,
                    'posts_per_page'      => absint( $featured_slider_number ),
                    'category__in'        => $ids,
                );

                // Fetch posts.
                $all_posts = get_posts( $qargs );
                $slides = array();

                if ( ! empty( $all_posts ) ) {

                    $cnt = 0;
                    foreach ( $all_posts as $key => $post ) {

                        if ( has_post_thumbnail( $post->ID ) ) {
                            $image_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'foodland-slider' );
                        }else{
                            $image_array = array ( get_template_directory_uri() . '/images/no-thumbnail-image-450x315.png' );
                        }

                        $slides[ $cnt ]['images']  = $image_array;
                        $slides[ $cnt ]['title']   = $post->post_title;
                        $slides[ $cnt ]['excerpt'] = foodland_slider_excerpt_limit( $options['slider_excerpt_length'], $post );
                        $slides[ $cnt ]['url']     = get_permalink( $post->ID );

                        $cnt++;
                    }
                }
                if ( ! empty( $slides ) ) {
                    $input = $slides;
                }
            break;

            case 'featured-image-slider':

                $ids = array();
                for ( $i = 1; $i <= absint( $featured_slider_number ); $i++ ) {
                    $ids[$i]['image']   = !empty( $options['featured_slider_image_' . $i ] ) ? $options[ 'featured_slider_image_' . $i ] : '' ;
                    $ids[$i]['title']   = !empty( $options['featured_title_' . $i ] ) ? $options[ 'featured_title_' . $i ] : '';
                    $ids[$i]['excerpt'] = !empty( $options['featured_content_' . $i ] ) ? $options[ 'featured_content_' . $i ] : '';
                    $ids[$i]['url']     = !empty( $options['featured_link_' . $i ] ) ? $options[ 'featured_link_' . $i ] : '#' ;
                }

                $slides = array();

                if ( ! empty( $ids ) ) {

                    $cnt = 1;
                    foreach ( $ids as $key => $slide ) {

                        if ( !empty( $slide ) ) {
                            if( !empty( $slide['image'] ) ){
                                $slides[ $cnt ]['images']  = wp_get_attachment_image_src( $slide['image'], 'foodland-slider' );
                                $slides[ $cnt ]['title']   = $slide['title'];
                                $slides[ $cnt ]['excerpt'] = $slide['excerpt'];
                                $slides[ $cnt ]['url']     = $slide['url'];
                                }
                            $cnt++;
                        }
                    }
                }
                if ( ! empty( $slides ) ) {
                    $input = $slides;
                }
            break;

            case 'featured-food-menus':

                $ids = array();

                for ( $i = 1; $i <= absint( $featured_slider_number ) ; $i++ ) {
                    $id = !empty( $options[ 'featured_nova_menu_' . $i ] ) ? $options[ 'featured_nova_menu_' . $i ] : '';
                    if ( ! empty( $id ) ) {
                        $ids[] = absint( $id );
                    }
                }
                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $qargs = array(
                    'post_type'      => 'nova_menu_item',
                    'posts_per_page' => absint( $featured_slider_number ),
                    'post__in'       => $ids,
                    'orderby'        => 'post__in',
                );

                // Fetch posts.
                $all_posts = get_posts( $qargs );
                $slides = array();

                if ( ! empty( $all_posts ) ) {

                    $cnt = 0;
                    foreach ( $all_posts as $key => $post ) {

                        if ( has_post_thumbnail( $post->ID ) ) {
                            $image_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'foodland-slider' );
                        }else{
                            $image_array = array ( get_template_directory_uri() . '/images/no-thumbnail-image-450x315.png' );
                        }

                        $slides[ $cnt ]['images']       = $image_array;
                        $slides[ $cnt ]['title']        = $post->post_title;
                        $slides[ $cnt ]['excerpt']      = foodland_slider_excerpt_limit( $options['slider_excerpt_length'], $post );
                        $slides[ $cnt ]['url']          = get_permalink( $post->ID );
                        
                        //extra options for jetpack food menu
                        $slides[ $cnt ]['menu_section'] = get_the_terms( $post->ID, 'nova_menu' );
                        $slides[ $cnt ]['rating']       = get_post_meta( $post->ID, 'menu_rating', true );
                        $slides[ $cnt ]['price']        = get_post_meta( $post->ID, 'nova_price', true );

                        $cnt++;
                    }
                }
                if ( ! empty( $slides ) ) {
                    $input = $slides;
                }
            break;

            default:
            break;
        }
        return $input;
    }
endif;

if ( ! function_exists( 'foodland_add_featured_slider' ) ) :
    /**
     * Add featured slider.
     *
     * @since Foodland 1.0
     */
    function foodland_add_featured_slider() {

        $flag_apply_slider = apply_filters( 'foodland_filter_slider_status', false );
        if ( true !== $flag_apply_slider ) {
            return false;
        }

        $slider_details = array();
        $slider_details = apply_filters( 'foodland_filter_slider_details', $slider_details );

        if ( empty( $slider_details ) ) {
            return;
        }

        // Render slider now.
        foodland_render_featured_slider( $slider_details );

    }
endif;

if ( ! function_exists( 'foodland_render_featured_slider' ) ) :
    /**
     * Render featured slider.
     *
     * @since Foodland 1.0
     *
     * @param array $slider_details Details of slider content.
     */
    function foodland_render_featured_slider( $slider_details = array() ) {

        if ( empty( $slider_details ) ) {
            return;
        }

        $options = foodland_get_theme_options();

        if( ( ! $foodland_featured_slider = get_transient( 'foodland_featured_slider' ) ) ) {
            echo '<!-- refreshing cache -->';
        $foodland_featured_slider = '';

            $foodland_featured_slider .= '
                <section id="feature-slider">
                    <div class="cycle-slideshow"
                        data-cycle-fx="carousel"
                        data-cycle-pause-on-hover="true"
                        data-cycle-log="false"
                        data-cycle-swipe="true"
                        data-cycle-loader="wait"
                        data-cycle-auto-height=container
                        data-cycle-carousel-visible=3
                        data-cycle-carousel-fluid=true
                        data-cycle-speed="' . absint( $options['featured_slide_transition_length'] ) * 1000 . '"
                        data-cycle-timeout="' . absint( $options['featured_slide_transition_delay'] ) * 1000 . '"
                        data-cycle-loop="' . esc_attr( absint( $options['featured_slide_loop'] ) ) .'"
                        data-cycle-prev="#prev"
                        data-cycle-next="#next"
                        data-cycle-slides="> article">';

                        $no_of_slides = $options['featured_slide_number'];

                            $count = 1; 

                            foreach ( $slider_details as $key => $slide ):

                                $post_thumbnail = $slide['images'];
                                $post_title     = $slide['title'];
                                $post_excerpt   = $slide['excerpt'];
                                $post_url       = $slide['url'];

                                // Check if jetpack plugin and featured-food-menus slider type is active
                                if( class_exists( 'jetpack' ) && ( $options['featured_slider_type'] == 'featured-food-menus' ) ){

                                    $menu_sections  = $slide['menu_section'];
                                    $menu_price     = $slide['price'];
                                    $menu_rating    = $slide['rating'];
                                    $section_name = array();

                                    if( $menu_sections ){ 
                                        // get taxonomy name and id 
                                        $i = 1;
                                        foreach( $menu_sections as $menu_section ) {
                                            $menu_section_name = $menu_section->name; // get taxonomy name
                                            $menu_section_term_id = $menu_section->term_id; // get taxonomy id
                                            
                                            $section_name[$i]['link'] = '<a href="' . esc_url(  get_term_link(  $menu_section_term_id, 'nova_menu' ) ) . '"><span class="title-head">'. esc_html( $menu_section_name ) . '</span></a>';
                                            $i++;
                                        }
                                    }else{
                                        $section_name = array();
                                    }

                                    // menu ratings
                                    if( !empty( $menu_rating ) ){
                                        $rating = foodland_get_menu_item_ratings( $menu_rating );
                                    } else {
                                        $rating = '';
                                    }
                                    // menu price
                                    if( !empty($menu_price) ){
                                        $fooditem_price = '<p class="dollar-cost"><span class="currency"></span>' . esc_html( $menu_price ) . '</p>';
                                    } else{
                                        $fooditem_price = '';
                                    }
                                } else{
                                    // empty value if jetpack is not active
                                    $section_name   = array();
                                    $rating         = '';
                                    $fooditem_price = '';
                                }

                                $foodland_featured_slider .= '
                                <article class="slides">
                                    <div class="item hover-on">';

                                        $foodland_featured_slider .= '<img src="' . esc_url( $post_thumbnail[0] ) . '" alt="' . esc_attr( $post_title ). '"/>';

                                        $foodland_featured_slider .= '
                                            <div class="product-info">
                                                <div class="pdt-name">';
                                                if( !empty( $post_title ) ){
                                                    $foodland_featured_slider .= '<h2 class="upercase">';
                                                    foreach ( $section_name as $section_names ) { 
                                                        $foodland_featured_slider .= $section_names['link']; 
                                                    }; 
                                                    $foodland_featured_slider .= '<h3><a href="' . esc_url( $post_url ) . '" >' . esc_html( $post_title ) . '</a></h3></h2>';
                                                }
                                                if( !empty( $rating ) ){
                                                    $foodland_featured_slider .= $rating;
                                                }

                                                if( !empty( $post_excerpt ) ) {
                                                    $foodland_featured_slider .= '<p class="slider-content">' . wp_kses_data( $post_excerpt ) . '</p>';
                                                }
                                                $foodland_featured_slider .= '
                                                </div><!-- .pdt-name -->
                                            <div class="pdt-cost">';
                                            
                                            if( !empty( $fooditem_price ) ){
                                                $foodland_featured_slider .= $fooditem_price; 
                                            }

                                            if( !empty( $options['link_button_text'] ) && !empty( $post_url ) ) {
                                                $foodland_featured_slider .= '<a class="rounded-btn upercase" href="' . esc_url( $post_url ) . '">' .esc_html( $options['link_button_text'] ) . '</a>';
                                            }

                                            $foodland_featured_slider .= '
                                            </div><!-- .pdt-cost -->
                                        </div><!-- .product-info -->
                                    </div><!-- .item -->
                                </article><!-- .slides -->';  
                            $count++;
                            endforeach;
                       
                    $foodland_featured_slider .= '
                    </div><!-- .cycle-slideshow -->
                    <div class="center">
                            <a href=# id="prev" class="prev"> Prev </a>
                            <a href=# id="next" class="next"> Next  </a>
                    </div><!-- .center -->
                </section><!-- #feature-slider -->';
                
            set_transient( 'foodland_featured_slider', $foodland_featured_slider, 86940 );
        }
        echo $foodland_featured_slider ;
    }
endif;

if( ! function_exists( 'foodland_check_slider_status' ) ) :

    /**
     * Check status of slider.
     *
     * @since Foodland 1.0
     */
    function foodland_check_slider_status( $input ) {
        global $post, $wp_query;

        $options = foodland_get_theme_options();
        // Slider status.
        $featured_slider_status = $options[ 'featured_slider_option' ];

        // Get Page ID outside Loop.
        $page_id = $wp_query->get_queried_object_id();

        // Front page displays in Reading Settings.
        $page_on_front  = absint( get_option( 'page_on_front' ) );
        $page_for_posts = absint( get_option( 'page_for_posts' ) );

        switch ( $featured_slider_status ) {
            case 'homepage':
                if ( $page_on_front === $page_id && $page_on_front > 0 ) {
                    $input = true;
                }
                break;
            case 'entire-site':
                $input = true;
                break;

            case 'disabled':
                $input = false;
                break;

            default:
                break;
        }
        return $input;

    }
endif;
