<?php
/**
 * Makes a custom Widget for Displaying Ads
 *
 * Learn more: http://codex.wordpress.org/Widgets_API#Developing_Widgets
 *
 * @package Theme Palace
 * @subpackage Foodland
 * @since Foodland 1.0
 */

class Foodland_adspace_widget extends WP_Widget {

	function __construct() {
		parent::__construct(
			'widget_foodland_adspace_widget', // Base ID
			__( 'TP: Advertisement', 'foodland' ), // Name
			array( 'description' => __( 'Use this widget to add any type of Advertisement as a widget', 'foodland' ) ) // Args
		);
	}

	/**
	 * Creates the form for the widget in the back-end which includes the Title , adcode, image, alt
	 * $instance Current settings
	 */
	function form($instance) {
		$instance 	= wp_parse_args(
						(array) $instance,
						array(
							'title' => '',
							'adcode' => '',
							'image' => '',
							'href' => '',
							'target' => '0',
							'alt' => ''
							)
					);
		$title 		= esc_attr( $instance[ 'title' ] );
		$adcode 	= esc_textarea( $instance[ 'adcode' ] );
		$image 		= esc_url( $instance[ 'image' ] );
		$href 		= esc_url( $instance[ 'href' ] );
		$target 	= $instance['target'] ? 'checked' : '';
		$alt 		= esc_attr( $instance[ 'alt' ] );
		if ( isset( $instance['enable_hide_404'] ) ) {
			if ( $instance['enable_hide_404'] ) {
				$enable_hide_404 = 'checked';
			}
			else {
				$enable_hide_404 = '';
			}
		}
		else {
			$enable_hide_404 = 'checked';
		}
		?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('title') ); ?>"><?php _e('Title (optional):','foodland'); ?></label>
            <input type="text" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" value="<?php echo esc_attr( $title ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" />
        </p>
        <?php if ( current_user_can( 'unfiltered_html' ) ) : // Only show it to users who can edit it ?>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('adcode') ); ?>"><?php _e('Advertisement Code:','foodland'); ?></label>
                <textarea name="<?php echo esc_attr( $this->get_field_name('adcode') ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id('adcode') ); ?>"><?php echo  wp_specialchars_decode( $adcode ); ?></textarea>
            </p>
            <p><strong>or</strong></p>
        <?php endif; ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('image') ); ?>"><?php _e('Image Url:','foodland'); ?></label>
        <input type="text" name="<?php echo esc_attr( $this->get_field_name('image') ); ?>" value="<?php echo esc_url( $image ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id('image') ); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('href') ); ?>"><?php _e('Link URL:','foodland'); ?></label>
            <input type="text" name="<?php echo esc_attr( $this->get_field_name('href') ); ?>" value="<?php echo esc_url( $href ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id('href') ); ?>" />
        </p>
		<p>
			<input class="checkbox" type="checkbox" <?php echo esc_attr( $target ); ?> id="<?php echo esc_attr( $this->get_field_id('target') ); ?>" name="<?php echo esc_attr( $this->get_field_name('target') ); ?>" /> <label for="<?php echo esc_attr( $this->get_field_id('target') ); ?>"><?php _e( 'Open Link in New Window', 'foodland' ); ?></label>
		</p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('alt') ); ?>"><?php _e('Alt text:','foodland'); ?></label>
            <input type="text" name="<?php echo esc_attr( $this->get_field_name('alt') ); ?>" value="<?php echo esc_attr( $alt ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id('alt') ); ?>" />
        </p>
        <p>
			<input class="checkbox" type="checkbox" <?php echo esc_attr( $enable_hide_404 ); ?> id="<?php echo esc_attr( $this->get_field_id('enable_hide_404') ); ?>" name="<?php echo esc_attr( $this->get_field_name('enable_hide_404') ); ?>" /> <label for="<?php echo esc_attr( $this->get_field_id('enable_hide_404') ); ?>"><?php _e( 'Check to Hide Ad on 404 page', 'foodland' ); ?></label>
		</p>
        <?php
	}

	/**
	 * update the particular instant
	 *
	 * This function should check that $new_instance is set correctly.
	 * The newly calculated value of $instance should be returned.
	 * If "false" is returned, the instance won't be saved/updated.
	 *
	 * $new_instance New settings for this instance as input by the user via form()
	 * $old_instance Old settings for this instance
	 * Settings to save or bool false to cancel saving
	 */
	function update( $new_instance, $old_instance ) {
		$instance             = $old_instance;
		$instance['title']    = strip_tags($new_instance['title']);
		$instance['adcode']   = wp_kses_stripslashes($new_instance['adcode']);
		$instance['image']    = esc_url_raw($new_instance['image']);
		$instance['href']     = esc_url_raw($new_instance['href']);
		$instance[ 'target' ] = isset( $new_instance[ 'target' ] ) ? 1 : 0;
		$instance['alt']      = sanitize_text_field($new_instance['alt']);

		$instance[ 'enable_hide_404' ] = isset( $new_instance[ 'enable_hide_404' ] ) ? 1 : 0;

		return $instance;
	}

	/**
	 * Displays the Widget in the front-end.
	 *
	 * $args Display arguments including before_title, after_title, before_widget, and after_widget.
	 * $instance The settings for the particular instance of the widget
	 */
	function widget( $args, $instance ) {
		extract( $args );
		extract( $instance );

		if ( isset( $instance['enable_hide_404'] ) && $instance['enable_hide_404'] && is_404() ) {
			//Bail Early if the page is 404 error page and the widget is set to be hidden in that page
			return;
		}


		$title 	= !empty( $instance['title'] ) ? $instance['title'] : '';
		$adcode = !empty( $instance['adcode'] ) ? $instance['adcode'] : '';
		$image 	= !empty( $instance['image'] ) ? $instance['image'] : '';
		$href 	= !empty( $instance['href'] ) ? $instance['href'] : '';
		$target = !empty( $instance['target' ] ) ? 'true' : 'false';
		$alt 	= !empty( $instance['alt'] ) ? $instance['alt'] : '';

		$enable_hide_404 = !empty( $instance[ 'enable_hide_404' ] ) ? 'true' : 'false';

		if ( $target == "true" ) :
			$base = '_blank';
		else:
			$base = '_self';
		endif;

		echo $before_widget;
		if ( $title != '' ) {
			echo $before_title . apply_filters( 'widget_title', $title, $instance, $this->id_base ) . $after_title;
		}

		if ( $adcode != '' ) {
			echo  wp_specialchars_decode( $adcode );
		}
		elseif ( $image != '' ) {
        	if( $href != '' ) {
        		echo '<a href="'. esc_url( $href ).'" target="'.esc_attr( $base ).'"><img src="'. esc_url( $image ).'" alt="'.esc_attr( $alt ).'" /></a>';
        	}
        	else {
        		echo '<img src="'. esc_url( $image ).'" alt="'.esc_attr( $alt ).'" />';
        	}
		}
		else {
			_e( 'Add Advertisement Code or Image URL', 'foodland' );
		}
		echo $after_widget;
	}

} // class Foodland_adspace_widget